Yujin Tools
=========

Utilies for yujin development. These are system tools (i.e. not deployed within a 
ros environment).

Template style wizard shortcuts for creating ros packages, stacks.

## Tools

* cfind 
* yujin_init_workspace

## Installation

    > sudo apt-get install python-pip
    > sudo pip install --upgrade yujin_tools


